@@ -117,6 +117,8 @@
 //!
 //! ## Recent changes
 //!
+//! * 0.6.2
+//!     * Feature `with_hyper` returns Response<Body>
 //! * 0.6.1
 //!     * Feature `with_hyper` returns response Vec<u8>
 //! * 0.6.0
@@ -424,7 +426,7 @@ impl HttpApiProblem {
     /// If status is `None` `500 - Internal Server Error` is the
     /// default.
     #[cfg(feature = "with_hyper")]
-    pub fn to_hyper_response(self) -> hyper::Response<Vec<u8>> {
+    pub fn to_hyper_response(self) -> hyper::Response<hyper::Body> {
         use hyper::header::{HeaderValue, CONTENT_LENGTH, CONTENT_TYPE};
         use hyper::StatusCode;
         use hyper::*;
@@ -438,8 +440,8 @@ impl HttpApiProblem {
             .status(status)
             .header(CONTENT_TYPE, HeaderValue::from_static(PROBLEM_JSON_MEDIA_TYPE))
             .header(CONTENT_LENGTH, HeaderValue::from_str(&length.to_string()).unwrap())
-            .body(json);
-        let response: Response<Vec<u8>> = builder.unwrap();
+            .body(json.into());
+        let response: Response<hyper::Body> = builder.unwrap();
 
         response
     }
@@ -499,14 +501,14 @@ impl From<HttpApiProblem> for ::iron::response::Response {
 /// If status is `None` `500 - Internal Server Error` is the
 /// default.
 #[cfg(feature = "with_hyper")]
-pub fn into_hyper_response<T: Into<HttpApiProblem>>(what: T) -> hyper::Response<Vec<u8>> {
+pub fn into_hyper_response<T: Into<HttpApiProblem>>(what: T) -> hyper::Response<hyper::Body> {
     let problem: HttpApiProblem = what.into();
     problem.to_hyper_response()
 }
 
 #[cfg(feature = "with_hyper")]
-impl From<HttpApiProblem> for hyper::Response<Vec<u8>> {
-    fn from(problem: HttpApiProblem) -> hyper::Response<Vec<u8>> {
+impl From<HttpApiProblem> for hyper::Response<hyper::Body> {
+    fn from(problem: HttpApiProblem) -> hyper::Response<hyper::Body> {
         problem.to_hyper_response()
     }
 }
